<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Member full card PDF
 *
 * PHP version 5
 *
 * Copyright © 2016 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  IO
 * @package   GaletteFullcard
 *
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2016 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @version   SVN: $Id$
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.9dev - 2016-03-02
 */

namespace GaletteFullcard;

use Galette\IO\PdfAdhesionForm;
use Galette\Core\Preferences;
use Galette\Core\Logo;
use Galette\Core\Db;
use Galette\Entity\Adherent;
use Galette\IO\Pdf;
use Analog\Analog;

/**
 * Member full card PDF
 *
 * @category  IO
 * @name      PDF
 * @package   Galette
 * @abstract  Class for expanding TCPDF.
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2016 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.9dev - 2016-03-02
 */

class PdfFullcard extends PdfAdhesionForm
{
    /**
     * Main constructor
     *
     * @param Adherent    $adh   Adherent
     * @param Db          $zdb   Database instance
     * @param Preferences $prefs Preferences instance
     */
    public function __construct(Adherent $adh = null, Db $zdb, Preferences $prefs)
    {
        $this->adh = $adh;
        $this->prefs = $prefs;
        $this->filename = _T('fullcard', 'fullcard') . '.pdf';

        $this->pdf = new Pdf($prefs);
        $this->init();
        $this->drawCard();
    }

    /**
     * Initialize PDF
     *
     * @return void
     */
    private function init()
    {
        // Set document information
        $this->pdf->SetTitle(_T('Member\'s full card', 'fullcard'));
        $this->pdf->SetSubject(_T('Generated by Galette', 'fullcard'));
        $this->pdf->SetKeywords(_T('Labels', 'fullcard'));

        $this->pdf->setMargins(10, 10);

        // Show full page
        $this->pdf->SetDisplayMode('fullpage');

        // Disable Auto Page breaks
        $this->pdf->SetAutoPageBreak(false, 20);
    }

    /**
     * Draw member cards
     *
     * @return void
     */
    private function drawCard()
    {
        $member = $this->adh;

        define('FULLCARD_FONT', Pdf::FONT_SIZE-2);
        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT);
        $this->pdf->SetTextColor(0, 0, 0);

        $this->pdf->AddPage();
        $picture = new Logo();
        $this->pdf->PageHeader(_T("Adhesion form"));

        $this->pdf->SetDrawColor(180, 180, 180);
        $this->pdf->SetLineWidth(0.1);

        $this->pdf->Ln(10);
        $this->pdf->Line($this->pdf->GetX(), $this->pdf->GetY(), 200, $this->pdf->GetY());
        $this->pdf->Ln(2);
        $this->pdf->SetTextColor(0, 0, 0);
        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT - 1);
        $this->pdf->MultiCell(0, 4, _T("Complete the following form and send it with your funds, in order to complete your subscription."), 0, 'L');

        $this->pdf->ln(2);
        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT);
        $this->pdf->SetX(100);
        $this->pdf->MultiCell(0, 4, $this->prefs->getPostalAddress(), 0, 'L');
        $this->pdf->Ln(3);
        $this->pdf->Line($this->pdf->GetX(), $this->pdf->GetY(), 200, $this->pdf->GetY());

        $this->pdf->Ln(10);
        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT + 2);

        //let's draw all fields
        $y = $this->pdf->GetY()+1;
        $this->pdf->Write(5, _T("Required membership:"));
        $this->pdf->SetX($this->pdf->GetX()+5);
        $this->pdf->Rect($this->pdf->GetX(), $y, 3, 3);
        $this->pdf->SetX($this->pdf->GetX()+(($member === null)?3:0));
        $this->pdf->Cell(3, 5, ($member !== null && $member->status == 4) ? "X" : "", 0, 0, 'C');

        $this->pdf->Write(5, _T("Active member"));
        $this->pdf->SetX($this->pdf->GetX()+5);
        $this->pdf->Rect($this->pdf->GetX(), $y, 3, 3);
        $this->pdf->SetX($this->pdf->GetX()+(($member === null)?3:0));
        $this->pdf->Cell(3, 5, ($member !== null && $member->status == 5) ? "X" : "", 0, 0, 'C');
        $this->pdf->Write(5, _T("Benefactor member"));
        $this->pdf->SetX($this->pdf->GetX()+5);
        $this->pdf->Rect($this->pdf->GetX(), $y, 3, 3);
        $this->pdf->SetX($this->pdf->GetX()+3);
        $this->pdf->Write(5, _T("Donation"));
        $this->pdf->Ln();
        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT);
        $this->pdf->Write(4, _T("The minimum contribution for each type of membership are defined on the website of the association. The amount of donations are free to be decided by the generous donor."));
        $this->pdf->Ln(20);

        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT + 2);
        $y = $this->pdf->GetY()+1;
        $this->pdf->Cell(30, 7, _T("Politeness"), 0, 0, 'L');
        $title = '';
        if ($member !== null && $member->title) {
            $title = $member->title->long;
        }
        $this->pdf->Cell(0, 7, $title, 0, 1, 'L');
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Cell(30, 7, _T("Name"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->name, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);
        $this->pdf->Cell(30, 7, _T("First name"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->surname, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);
        $this->pdf->Cell(30, 7, _T("Company name") . " *", 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->company_name, 0, 1, 'L');
        }

        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Cell(30, 7, _T("Address"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->address, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);
        $this->pdf->SetY($this->pdf->GetY() + 7);
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->address_continuation, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);
        $this->pdf->SetY($this->pdf->GetY() + 7);
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $y = $this->pdf->GetY();
        $this->pdf->Cell(30, 7, _T("Zip Code"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->zipcode, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, $this->pdf->GetX()+30+15, $this->pdf->GetY()-1);
        $this->pdf->SetY($y);
        $this->pdf->SetX($this->pdf->GetX()+30+15+5);
        $this->pdf->Cell(30, 7, _T("City"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->town, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30+15+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Cell(30, 7, _T("Country"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->country, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Cell(30, 7, _T("Email address"), 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->email, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Cell(30, 7, _T("Username") ." **", 0, (($member === null)?1:0), 'L');
        if ($member !== null) {
            $this->pdf->Cell(0, 7, $member->login, 0, 1, 'L');
        }
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Ln(6);
        $this->pdf->Cell(30, 7, _T("Amount"), 0, 1, 'L');
        $this->pdf->Line($this->pdf->GetX()+30, $this->pdf->GetY()-1, 190, $this->pdf->GetY()-1);

        $this->pdf->Ln(10);
        $this->pdf->Write(
            4,
            preg_replace(
                '/%s/',
                $this->prefs->pref_nom,
                _T("Hereby, I agree to comply to %s association statutes and its rules.")
            )
        );
        $this->pdf->Ln(10);
        $this->pdf->Cell(64, 5, _T("At ", "fullcard"), 0, 0, 'L');
        $this->pdf->Cell(0, 5, _T("On            /            /            ", "fullcard"), 0, 1, 'L');
        $this->pdf->Ln(1);
        $this->pdf->Cell(0, 5, _T("Signature"), 0, 1, 'L');


        $this->pdf->SetY(260);
        $this->pdf->SetFont(Pdf::FONT, '', FULLCARD_FONT - 2);
        $this->pdf->Cell(0, 3, _T("* Only for compagnies"), 0, 1, 'R');
        $this->pdf->Cell(0, 3, _T("** Galette identifier, if applicable"), 0, 1, 'R');
    }
}
